@@ -21,7 +21,7 @@ use JSON;
 use URI::Template;
 use RDF::LDF::Error;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 {
    my $ua   = RDF::Trine->default_useragent;
    $ua->agent("RDF:::LDF/$RDF::LDF::VERSION " . $ua->_agent);
@@ -659,14 +659,14 @@ Returns a stream object of all bindings matching the specified graph pattern.
 
 =back
 
-=head1 AUTHOR
+=head1 CONTRIBUTORS
 
 Patrick Hochstenbach, C<< patrick.hochstenbach at ugent.be >>
 
-=head1 CONTRIBUTORS
-
 Gregory Todd Williams, C<< greg@evilfunhouse.com >>
 
+Jacob Voss, C<<voss@gbv.de>>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Patrick Hochstenbach.
